use crate::prelude::*;

#[derive(Debug)]
pub enum DataError {
    IOError(std::io::Error),
    Report(Box<ariadne::Report<'static, io::Span>>),
}

impl std::fmt::Display for DataError {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        <Self as std::fmt::Debug>::fmt(self, f)
    }
}

impl From<std::io::Error> for DataError {
    fn from(value: std::io::Error) -> Self {
        Self::IOError(value)
    }
}

impl From<ariadne::Report<'static, io::Span>> for DataError {
    fn from(value: ariadne::Report<'static, io::Span>) -> Self {
        Self::Report(value.into())
    }
}

impl std::error::Error for DataError {}
